@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminGenericInterfaceWebservice.pm - provides a webservice view for admins
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -509,7 +508,11 @@ sub Run {
         }
 
         # check if imported configuration has current framework version otherwise update it
-        if ( $ImportedConfig->{FrameworkVersion} ne $Self->{FrameworkVersion} ) {
+        if (
+            !$ImportedConfig->{FrameworkVersion}
+            || $ImportedConfig->{FrameworkVersion} ne $Self->{FrameworkVersion}
+            )
+        {
             $ImportedConfig = $Self->_UpdateConfiguration( Configuration => $ImportedConfig );
         }
 
