@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminProcessManagement.pm - process management
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -495,13 +494,70 @@ sub Run {
             );
         }
 
+        # determine skin for selection of the correct logo
+        # 1. use UserSkin setting from Agent preferences, if available
+        # 2. use HostBased skin setting, if available
+        # 3. use default skin from configuration
+
+        my $SkinSelectedHostBased;
+        my $DefaultSkinHostBased = $Self->{ConfigObject}->Get('Loader::Agent::DefaultSelectedSkin::HostBased');
+        if ( $DefaultSkinHostBased && $ENV{HTTP_HOST} ) {
+            REGEXP:
+            for my $RegExp ( sort keys %{$DefaultSkinHostBased} ) {
+
+                # do not use empty regexp or skin directories
+                next REGEXP if !$RegExp;
+                next REGEXP if !$DefaultSkinHostBased->{$RegExp};
+
+                # check if regexp is matching
+                if ( $ENV{HTTP_HOST} =~ /$RegExp/i ) {
+                    $SkinSelectedHostBased = $DefaultSkinHostBased->{$RegExp};
+                }
+            }
+        }
+
+        my $SkinSelected = $Self->{'UserSkin'};
+
+        # check if the skin is valid
+        my $SkinValid = 0;
+        if ($SkinSelected) {
+            $SkinValid = $Self->{LayoutObject}->SkinValidate(
+                SkinType => 'Agent',
+                Skin     => $SkinSelected,
+            );
+        }
+
+        if ( !$SkinValid ) {
+            $SkinSelected = $SkinSelectedHostBased
+                || $Self->{ConfigObject}->Get('Loader::Agent::DefaultSelectedSkin')
+                || 'default';
+        }
+
+        my %AgentLogo;
+
+        # check if we need to display a custom logo for the selected skin
+        my $AgentLogoCustom = $Self->{ConfigObject}->Get('AgentLogoCustom');
+        if (
+            $SkinSelected
+            && $AgentLogoCustom
+            && IsHashRefWithData($AgentLogoCustom)
+            && $AgentLogoCustom->{$SkinSelected}
+            )
+        {
+            %AgentLogo = %{ $AgentLogoCustom->{$SkinSelected} };
+        }
+
+        # Otherwise show default header logo, if configured
+        elsif ( defined $Self->{ConfigObject}->Get('AgentLogo') ) {
+            %AgentLogo = %{ $Self->{ConfigObject}->Get('AgentLogo') };
+        }
+
         # get logo
-        my $Logo = $Self->{ConfigObject}->Get('AgentLogo');
-        if ( $Logo && %{$Logo} ) {
+        if ( $AgentLogo{URL} ) {
             $Self->{LayoutObject}->Block(
                 Name => 'Logo',
                 Data => {
-                    LogoURL => $Param{LogoURL} = $Self->{ConfigObject}->Get('Frontend::WebPath') . $Logo->{URL},
+                    LogoURL => $Self->{ConfigObject}->Get('Frontend::WebPath') . $AgentLogo{URL},
                 },
             );
         }
@@ -1466,8 +1522,11 @@ sub _ShowOverview {
 
     if ( IsHashRefWithData($ProcessList) ) {
 
+        # Sort process list by name instead of ID (bug#12311).
+        my @ProcessIDs = sort { lc $ProcessList->{$a} cmp lc $ProcessList->{$b} } keys %{$ProcessList};
+
         # get each process data
-        for my $ProcessID ( sort keys %{$ProcessList} ) {
+        for my $ProcessID (@ProcessIDs) {
             my $ProcessData = $Self->{ProcessObject}->ProcessGet(
                 ID     => $ProcessID,
                 UserID => $Self->{UserID},
@@ -1755,37 +1814,85 @@ sub _CheckEntityUsage {
             Method => 'ProcessListGet',
             Array  => 'Transitions',
         },
-        TransitionAction => {
-            Parent => 'Transition',
-            Method => 'TransitionListGet',
-            Array  => 'TransitionActions',
-        },
-    );
-
-    return if !$Config{ $Param{EntityType} };
-
-    my $Parent = $Config{ $Param{EntityType} }->{Parent};
-    my $Method = $Config{ $Param{EntityType} }->{Method};
-    my $Array  = $Config{ $Param{EntityType} }->{Array};
-
-    # get a list of parents with all the details
-    my $List = $Self->{ $Parent . 'Object' }->$Method(
-        UserID => 1,
     );
 
     my @Usage;
 
-    # search entity id in all parents
-    PARENT:
-    for my $ParentData ( @{$List} ) {
-        next PARENT if !$ParentData;
-        next PARENT if !$ParentData->{$Array};
+    # transition action needs to be handled on a different way than other process parts as it does
+    # not depend directly on a parent part, it is nested in the process path configuration
+    if ( $Param{EntityType} eq 'TransitionAction' ) {
 
-        ENTITY:
-        for my $EntityID ( @{ $ParentData->{$Array} } ) {
-            if ( $EntityID eq $Param{EntityID} ) {
-                push @Usage, $ParentData->{Name};
-                last ENTITY;
+        my $ProcessList = $Self->{ProcessObject}->ProcessListGet(
+            UserID => $Self->{UserID},
+        );
+
+        # search in all processes
+        PROCESS:
+        for my $Process ( @{$ProcessList} ) {
+
+            next PROCESS if !$Process->{Config}->{Path};
+            my $Path = $Process->{Config}->{Path};
+
+            # search on each activity on the process path
+            ACTIVITY:
+            for my $ActivityEntityID ( sort keys %{$Path} ) {
+
+                # search on each transition on the activity
+                TRANSITION:
+                for my $TransitionEntityID ( sort keys %{ $Path->{$ActivityEntityID} } ) {
+
+                    next TRANSITION if !$Path->{$ActivityEntityID}->{$TransitionEntityID};
+                    my $TransitionConfig = $Path->{$ActivityEntityID}->{$TransitionEntityID};
+
+                    next TRANSITION if !$TransitionConfig->{TransitionAction};
+                    my @TransitionActions = @{ $TransitionConfig->{TransitionAction} };
+
+                    ENTITY:
+                    for my $EntityID (@TransitionActions) {
+                        if ( $EntityID eq $Param{EntityID} ) {
+                            my $TransitionData = $Self->{TransitionObject}->TransitionGet(
+                                EntityID => $TransitionEntityID,
+                                UserID   => $Self->{UserID},
+                            );
+                            my $ActivityData = $Self->{ActivityObject}->ActivityGet(
+                                EntityID => $ActivityEntityID,
+                                UserID   => $Self->{UserID},
+                            );
+
+                            push @Usage, "$Process->{Name} -> $ActivityData->{Name} -> $TransitionData->{Name}";
+                            last ENTITY;
+                        }
+                    }
+                }
+            }
+        }
+    }
+    else {
+
+        return if !$Config{ $Param{EntityType} };
+
+        my $Parent = $Config{ $Param{EntityType} }->{Parent};
+        my $Method = $Config{ $Param{EntityType} }->{Method};
+        my $Array  = $Config{ $Param{EntityType} }->{Array};
+
+        # get a list of parents with all the details
+        my $List = $Self->{ $Parent . 'Object' }->$Method(
+            UserID => 1,
+        );
+
+        # search entity id in all parents
+        PARENT:
+        for my $ParentData ( @{$List} ) {
+
+            next PARENT if !$ParentData;
+            next PARENT if !$ParentData->{$Array};
+
+            ENTITY:
+            for my $EntityID ( @{ $ParentData->{$Array} } ) {
+                if ( $EntityID eq $Param{EntityID} ) {
+                    push @Usage, $ParentData->{Name};
+                    last ENTITY;
+                }
             }
         }
     }
