@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminProcessManagementTransitionAction.pm - process management transition action
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -544,10 +543,12 @@ sub _ShowEdit {
         Filter    => '*.pm',
     );
     my %TransitionAction;
+    ITEM:
     for my $Item (@List) {
 
         # remove .pm
         $Item =~ s/^.*\/(.+?)\.pm$/$1/;
+        next ITEM if $Item eq 'Base';
         $TransitionAction{ 'Kernel::System::ProcessManagement::TransitionAction::' . $Item } = $Item;
     }
 
