@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminSalutation.pm - to add/update/delete system addresses
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -71,9 +70,13 @@ sub Run {
 
         my $Note = '';
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Text Comment ValidID)) {
+        for my $Parameter (qw(ID Name Comment ValidID)) {
             $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
+        $GetParam{'Text'} = $Self->{ParamObject}->GetParam(
+            Param => 'Text',
+            Raw   => 1
+        ) || '';
 
         # get content type
         my $ContentType = 'text/plain';
@@ -158,9 +161,13 @@ sub Run {
 
         my $Note = '';
         my ( %GetParam, %Errors );
-        for my $Parameter (qw(ID Name Text Comment ValidID)) {
+        for my $Parameter (qw(ID Name Comment ValidID)) {
             $GetParam{$Parameter} = $Self->{ParamObject}->GetParam( Param => $Parameter ) || '';
         }
+        $GetParam{'Text'} = $Self->{ParamObject}->GetParam(
+            Param => 'Text',
+            Raw   => 1
+        ) || '';
 
         # get content type
         my $ContentType = 'text/plain';
