@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AgentTicketBulk.pm - to do bulk actions on tickets
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -122,6 +121,125 @@ sub Run {
 
     }
 
+    elsif ( $Self->{Subaction} eq 'AJAXUpdate' ) {
+        my $QueueID = $Self->{ParamObject}->GetParam( Param => 'QueueID' ) || '';
+
+        # Get all users.
+        my %AllGroupsMembers = $Self->{UserObject}->UserList(
+            Type  => 'Long',
+            Valid => 1
+        );
+
+        # Put only possible 'owner' and 'rw' agents to owner list.
+        my %OwnerGroupsMembers;
+        if ( !$Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
+            my %AllGroupsMembersNew;
+            my @QueueIDs;
+
+            if ($QueueID) {
+                push @QueueIDs, $QueueID;
+            }
+            else {
+                my @TicketIDs = grep {$_} $Self->{ParamObject}->GetArray( Param => 'TicketID' );
+                for my $TicketID (@TicketIDs) {
+                    my %Ticket = $Self->{TicketObject}->TicketGet(
+                        TicketID      => $TicketID,
+                        DynamicFields => 0,
+                    );
+                    push @QueueIDs, $Ticket{QueueID};
+                }
+            }
+
+            for my $QueueID (@QueueIDs) {
+                my $GroupID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $QueueID );
+                my %GroupMember = $Self->{GroupObject}->GroupMemberList(
+                    GroupID => $GroupID,
+                    Type    => 'owner',
+                    Result  => 'HASH',
+                );
+                USER_ID:
+                for my $UserID ( sort keys %GroupMember ) {
+                    next USER_ID if !$AllGroupsMembers{$UserID};
+                    $AllGroupsMembersNew{$UserID} = $AllGroupsMembers{$UserID};
+                }
+                %OwnerGroupsMembers = %AllGroupsMembersNew;
+            }
+        }
+        else {
+            %OwnerGroupsMembers = %AllGroupsMembers;
+        }
+
+        my @JSONData = (
+            {
+                Name         => 'OwnerID',
+                Data         => \%OwnerGroupsMembers,
+                PossibleNone => 1,
+            }
+        );
+
+        if (
+            $Self->{ConfigObject}->Get('Ticket::Responsible')
+            && $Self->{ConfigObject}->Get("Ticket::Frontend::$Self->{Action}")->{Responsible}
+            )
+        {
+
+            my %ResponsibleGroupsMembers;
+            if ( !$Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
+                my %AllGroupsMembersNew;
+                my @QueueIDs;
+
+                if ($QueueID) {
+                    push @QueueIDs, $QueueID;
+                }
+                else {
+                    my @TicketIDs = grep {$_} $Self->{ParamObject}->GetArray( Param => 'TicketID' );
+                    for my $TicketID (@TicketIDs) {
+                        my %Ticket = $Self->{TicketObject}->TicketGet(
+                            TicketID      => $TicketID,
+                            DynamicFields => 0,
+                        );
+                        push @QueueIDs, $Ticket{QueueID};
+                    }
+                }
+
+                # Put only possible 'responsible' and 'rw' agents to responsible list.
+                for my $QueueID (@QueueIDs) {
+                    my $GroupID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $QueueID );
+                    my %GroupMember = $Self->{GroupObject}->GroupMemberList(
+                        GroupID => $GroupID,
+                        Type    => 'responsible',
+                        Result  => 'HASH',
+                    );
+
+                    USER_ID:
+                    for my $UserID ( sort keys %GroupMember ) {
+                        next USER_ID if !$AllGroupsMembers{$UserID};
+                        $AllGroupsMembersNew{$UserID} = $AllGroupsMembers{$UserID};
+                    }
+                    %ResponsibleGroupsMembers = %AllGroupsMembersNew;
+                }
+            }
+            else {
+                %ResponsibleGroupsMembers = %AllGroupsMembers;
+            }
+
+            push @JSONData, {
+                Name         => 'ResponsibleID',
+                Data         => \%ResponsibleGroupsMembers,
+                PossibleNone => 1,
+            };
+        }
+
+        my $JSON = $Self->{LayoutObject}->BuildSelectionJSON( [@JSONData] );
+
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'application/json; charset=' . $Self->{LayoutObject}->{Charset},
+            Content     => $JSON,
+            Type        => 'inline',
+            NoCache     => 1,
+        );
+    }
+
     # check if bulk feature is enabled
     if ( !$Self->{ConfigObject}->Get('Ticket::Frontend::BulkFeature') ) {
         return $Self->{LayoutObject}->ErrorScreen(
@@ -225,8 +343,7 @@ sub Run {
         # check some stuff
         if (
             $GetParam{Subject}
-            &&
-            $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime')
+            && $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime')
             && $Self->{ConfigObject}->Get('Ticket::Frontend::NeedAccountedTime')
             && $GetParam{TimeUnits} eq ''
             )
@@ -236,8 +353,7 @@ sub Run {
 
         if (
             $GetParam{EmailSubject}
-            &&
-            $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime')
+            && $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime')
             && $Self->{ConfigObject}->Get('Ticket::Frontend::NeedAccountedTime')
             && $GetParam{EmailTimeUnits} eq ''
             )
@@ -322,6 +438,9 @@ sub Run {
     my $Counter       = 1;
     $Param{TicketsWereLocked} = 0;
 
+    my @TicketsWithError;
+    my @TicketsWithLockNotice;
+
     TICKET_ID:
     for my $TicketID (@TicketIDs) {
         my %Ticket = $Self->{TicketObject}->TicketGet(
@@ -338,29 +457,14 @@ sub Run {
         if ( !$Access ) {
 
             # error screen, don't show ticket
-            $Output .= $Self->{LayoutObject}->Notify(
-                Data => "$Ticket{TicketNumber}: "
-                    . $Self->{LayoutObject}->{LanguageObject}->Translate("You don't have write access to this ticket."),
-            );
+            push @TicketsWithError, $Ticket{TicketNumber};
             next TICKET_ID;
         }
 
         # check if it's already locked by somebody else
-        if ( !$Self->{Config}->{RequiredLock} ) {
-            $Output .= $Self->{LayoutObject}->Notify(
-                Data => "$Ticket{TicketNumber}: "
-                    . $Self->{LayoutObject}->{LanguageObject}->Translate("Ticket selected."),
-            );
-        }
-        else {
+        if ( $Self->{Config}->{RequiredLock} ) {
             if ( grep ( { $_ eq $TicketID } @IgnoreLockedTicketIDs ) ) {
-                $Output .= $Self->{LayoutObject}->Notify(
-                    Priority => 'Error',
-                    Data     => "$Ticket{TicketNumber}: "
-                        . $Self->{LayoutObject}->{LanguageObject}->Translate(
-                        "Ticket is locked by another agent and will be ignored!"
-                        ),
-                );
+                push @TicketsWithError, $Ticket{TicketNumber};
                 next TICKET_ID;
             }
             else {
@@ -381,10 +485,8 @@ sub Run {
                 UserID    => $Self->{UserID},
                 NewUserID => $Self->{UserID},
             );
-            $Output .= $Self->{LayoutObject}->Notify(
-                Data => "$Ticket{TicketNumber}: "
-                    . $Self->{LayoutObject}->{LanguageObject}->Translate("Ticket locked."),
-            );
+
+            push @TicketsWithLockNotice, $Ticket{TicketNumber};
         }
 
         # remember selected ticket ids
@@ -396,6 +498,16 @@ sub Run {
             # challenge token check for write action
             $Self->{LayoutObject}->ChallengeTokenCheck();
 
+            # set queue
+            if ( $GetParam{'QueueID'} || $GetParam{'Queue'} ) {
+                $Self->{TicketObject}->TicketQueueSet(
+                    QueueID  => $GetParam{'QueueID'},
+                    Queue    => $GetParam{'Queue'},
+                    TicketID => $TicketID,
+                    UserID   => $Self->{UserID},
+                );
+            }
+
             # set owner
             if ( $Self->{Config}->{Owner} && ( $GetParam{'OwnerID'} || $GetParam{'Owner'} ) ) {
                 $Self->{TicketObject}->TicketOwnerSet(
@@ -404,6 +516,13 @@ sub Run {
                     NewUser   => $GetParam{'Owner'},
                     NewUserID => $GetParam{'OwnerID'},
                 );
+                if ( !$Self->{Config}->{RequiredLock} && $Ticket{StateType} !~ /^close/i ) {
+                    $Self->{TicketObject}->TicketLockSet(
+                        TicketID => $TicketID,
+                        Lock     => 'lock',
+                        UserID   => $Self->{UserID},
+                    );
+                }
             }
 
             # set responsible
@@ -446,16 +565,6 @@ sub Run {
                 }
             }
 
-            # set queue
-            if ( $GetParam{'QueueID'} || $GetParam{'Queue'} ) {
-                $Self->{TicketObject}->TicketQueueSet(
-                    QueueID  => $GetParam{'QueueID'},
-                    Queue    => $GetParam{'Queue'},
-                    TicketID => $TicketID,
-                    UserID   => $Self->{UserID},
-                );
-            }
-
             # send email
             my $EmailArticleID;
             if (
@@ -747,6 +856,32 @@ sub Run {
         $Counter++;
     }
 
+    # notify user about actions (errors)
+    if (@TicketsWithError) {
+        my $NotificationError = $Self->{LayoutObject}->{LanguageObject}->Translate(
+            "The following tickets were ignored because they are locked by another agent or you don't have write access to these tickets: %s.",
+            join( ", ", @TicketsWithError ),
+        );
+
+        $Output .= $Self->{LayoutObject}->Notify(
+            Priority => 'Error',
+            Data     => $NotificationError,
+        );
+    }
+
+    # notify user about actions (notices)
+    if (@TicketsWithLockNotice) {
+        my $NotificationNotice = $Self->{LayoutObject}->{LanguageObject}->Translate(
+            "The following tickets were locked: %s.",
+            join( ", ", @TicketsWithLockNotice ),
+        );
+
+        $Output .= $Self->{LayoutObject}->Notify(
+            Priority => 'Notice',
+            Data     => $NotificationNotice,
+        );
+    }
+
     # redirect
     if ($ActionFlag) {
         return $Self->{LayoutObject}->PopupClose(
@@ -899,7 +1034,7 @@ sub _Mask {
             Valid => 1
         );
 
-        # only put possible rw agents to possible owner list
+        # Put only possible 'owner' and 'rw' agents to owner list.
         if ( !$Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
             my %AllGroupsMembersNew;
             for my $TicketID ( @{ $Param{TicketIDs} } ) {
@@ -910,7 +1045,7 @@ sub _Mask {
                 my $GroupID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $Ticket{QueueID} );
                 my %GroupMember = $Self->{GroupObject}->GroupMemberList(
                     GroupID => $GroupID,
-                    Type    => 'rw',
+                    Type    => 'owner',
                     Result  => 'HASH',
                 );
                 USER_ID:
@@ -941,7 +1076,7 @@ sub _Mask {
             Valid => 1
         );
 
-        # only put possible rw agents to possible owner list
+        # Put only possible 'responsible' and 'rw' agents to responsible list.
         if ( !$Self->{ConfigObject}->Get('Ticket::ChangeOwnerToEveryone') ) {
             my %AllGroupsMembersNew;
             for my $TicketID ( @{ $Param{TicketIDs} } ) {
@@ -952,7 +1087,7 @@ sub _Mask {
                 my $GroupID = $Self->{QueueObject}->GetQueueGroupID( QueueID => $Ticket{QueueID} );
                 my %GroupMember = $Self->{GroupObject}->GroupMemberList(
                     GroupID => $GroupID,
-                    Type    => 'rw',
+                    Type    => 'responsible',
                     Result  => 'HASH',
                 );
                 USER_ID:
@@ -964,13 +1099,11 @@ sub _Mask {
             }
         }
         $Param{ResponsibleStrg} = $Self->{LayoutObject}->BuildSelection(
-            Data => {
-                '' => '-',
-                %AllGroupsMembers
-            },
-            Name        => 'ResponsibleID',
-            Translation => 0,
-            SelectedID  => $Param{ResponsibleID},
+            Data         => \%AllGroupsMembers,
+            PossibleNone => 1,
+            Name         => 'ResponsibleID',
+            Translation  => 0,
+            SelectedID   => $Param{ResponsibleID},
         );
         $Self->{LayoutObject}->Block(
             Name => 'Responsible',
@@ -1069,13 +1202,13 @@ sub _Mask {
     $Param{LinkTogetherYesNoOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => $Self->{ConfigObject}->Get('YesNoOptions'),
         Name       => 'LinkTogether',
-        SelectedID => $Param{LinkTogether} || 0,
+        SelectedID => $Param{LinkTogether} // 0,
     );
 
     $Param{UnlockYesNoOption} = $Self->{LayoutObject}->BuildSelection(
         Data       => $Self->{ConfigObject}->Get('YesNoOptions'),
         Name       => 'Unlock',
-        SelectedID => $Param{Unlock} || 1,
+        SelectedID => $Param{Unlock} // 1,
     );
 
     # show spell check
