@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -209,7 +209,6 @@ sub Run {
     for my $DynamicField ( sort keys %DynamicFieldValues ) {
         next DYNAMICFIELD if !$DynamicField;
         next DYNAMICFIELD if !defined $DynamicFieldValues{$DynamicField};
-        next DYNAMICFIELD if !length $DynamicFieldValues{$DynamicField};
 
         $DynamicFieldACLParameters{ 'DynamicField_' . $DynamicField } = $DynamicFieldValues{$DynamicField};
     }
@@ -267,6 +266,12 @@ sub Run {
         $GetParam{'UserSelection::New'} = 'checked="checked"';
     }
 
+    # Check if TreeView list type is activated.
+    my $TreeView = 0;
+    if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ListType') eq 'tree' ) {
+        $TreeView = 1;
+    }
+
     # Ajax update
     if ( $Self->{Subaction} eq 'AJAXUpdate' ) {
         my $ElementChanged = $Self->{ParamObject}->GetParam( Param => 'ElementChanged' ) || '';
@@ -295,6 +300,11 @@ sub Run {
             TicketID => $Self->{TicketID},
             QueueID  => $GetParam{DestQueueID} || 1,
         );
+        my $DestQueues = $Self->_GetQueues(
+            %GetParam,
+            %ACLCompatGetParam,
+            TicketID => $Self->{TicketID},
+        );
 
         # update Dynamic Fields Possible Values via AJAX
         my @DynamicFieldAJAX;
@@ -473,6 +483,15 @@ sub Run {
                     Translation  => 1,
                     Max          => 100,
                 },
+                {
+                    Name         => 'DestQueueID',
+                    Data         => $DestQueues,
+                    SelectedID   => $GetParam{DestQueueID},
+                    PossibleNone => 1,
+                    Translation  => 0,
+                    TreeView     => $TreeView,
+                    Max          => 100,
+                },
                 @DynamicFieldAJAX,
                 @TemplateAJAX,
             ],
@@ -1706,4 +1725,18 @@ sub _GetStandardTemplates {
     return $StandardTemplates{Note};
 }
 
+sub _GetQueues {
+    my ( $Self, %Param ) = @_;
+
+    # Get Queues.
+    my %Queues = $Self->{TicketObject}->TicketMoveList(
+        %Param,
+        TicketID => $Self->{TicketID},
+        UserID   => $Self->{UserID},
+        Action   => $Self->{Action},
+        Type     => 'move_into',
+    );
+    return \%Queues;
+}
+
 1;
