@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -156,7 +156,7 @@ sub Run {
     # get search string params (get submitted params)
     else {
         for my $Key (
-            qw(TicketNumber Title From To Cc Subject Body CustomerID CustomerUserLogin StateType
+            qw(TicketNumber Title From To Cc Subject Body CustomerID CustomerIDRaw CustomerUserLogin StateType
             Agent ResultForm TimeSearchType ChangeTimeSearchType CloseTimeSearchType LastChangeTimeSearchType EscalationTimeSearchType
             UseSubQueues AttachmentName
             ArticleTimeSearchType SearchInArchive
@@ -732,6 +732,17 @@ sub Run {
                         $Self->{TicketObject}->TicketAccountedTimeGet( TicketID => $TicketID ),
                 );
 
+                # Transform EscalationTime and EscalationTimeWorkingTime to a human readable format.
+                # See bug#13088 (https://bugs.otrs.org/show_bug.cgi?id=13088).
+                $Info{EscalationTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age   => $Info{EscalationTime},
+                    Space => ' ',
+                );
+                $Info{EscalationTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+                    Age   => $Info{EscalationTimeWorkingTime},
+                    Space => ' ',
+                );
+
                 my @Data;
                 for my $Header (@TmpCSVHead) {
 
