@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/CustomerTicketZoom.pm - to get a closer view
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -51,6 +50,19 @@ sub new {
         $Self->{ZoomExpand} = $Self->{ConfigObject}->Get('Ticket::Frontend::ZoomExpand') || '';
     }
 
+    if ( !defined $Self->{DoNotShowBrowserLinkMessage} ) {
+        my %UserPreferences = $Self->{UserObject}->GetPreferences(
+            UserID => $Self->{UserID},
+        );
+
+        if ( $UserPreferences{UserCustomerDoNotShowBrowserLinkMessage} ) {
+            $Self->{DoNotShowBrowserLinkMessage} = 1;
+        }
+        else {
+            $Self->{DoNotShowBrowserLinkMessage} = 0;
+        }
+    }
+
     # needed objects
     $Self->{AgentUserObject}    = Kernel::System::User->new(%Param);
     $Self->{StateObject}        = Kernel::System::State->new(%Param);
@@ -232,7 +244,6 @@ sub Run {
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{FollowUpDynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
-            next DYNAMICFIELD if $DynamicFieldConfig->{ObjectType} ne 'Ticket';
 
             my $IsACLReducible = $Self->{BackendObject}->HasBehavior(
                 DynamicFieldConfig => $DynamicFieldConfig,
@@ -312,6 +323,23 @@ sub Run {
 
     #   end AJAX Update
 
+    # save, if browser link message was closed
+    elsif ( $Self->{Subaction} eq 'BrowserLinkMessage' ) {
+
+        $Self->{UserObject}->SetPreferences(
+            UserID => $Self->{UserID},
+            Key    => 'UserCustomerDoNotShowBrowserLinkMessage',
+            Value  => 1,
+        );
+
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'text/html',
+            Content     => 1,
+            Type        => 'inline',
+            NoCache     => 1,
+        );
+    }
+
     # check follow up
     elsif ( $Self->{Subaction} eq 'Store' ) {
 
@@ -1107,6 +1135,7 @@ sub _Mask {
             my $ACL = $Self->{TicketObject}->TicketAcl(
                 Data           => \%PermissionActivityDialogList,
                 TicketID       => $Param{TicketID},
+                Action         => $Self->{Action},
                 ReturnType     => 'ActivityDialog',
                 ReturnSubType  => '-',
                 CustomerUserID => $Self->{UserID},
@@ -1157,7 +1186,7 @@ sub _Mask {
     for my $DynamicFieldConfig ( @{$DynamicField} ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
-        # skip the dynamic field if is not desinged for customer interface
+        # skip the dynamic field if is not designed for customer interface
         my $IsCustomerInterfaceCapable = $Self->{BackendObject}->HasBehavior(
             DynamicFieldConfig => $DynamicFieldConfig,
             Behavior           => 'IsCustomerInterfaceCapable',
@@ -1169,7 +1198,7 @@ sub _Mask {
             ObjectID           => $Param{TicketID},
         );
 
-        next DYNAMICFIELD if !$Value;
+        next DYNAMICFIELD if !defined $Value;
         next DYNAMICFIELD if $Value eq "";
 
         # get print string for this dynamic field
@@ -1388,6 +1417,13 @@ sub _Mask {
                             %Article,
                         },
                     );
+
+                    # show message about links in iframes, if user didn't close it already
+                    if ( !$Self->{DoNotShowBrowserLinkMessage} ) {
+                        $Self->{LayoutObject}->Block(
+                            Name => 'BrowserLinkMessage',
+                        );
+                    }
                 }
                 else {
                     my $SessionInformation;
@@ -1406,6 +1442,13 @@ sub _Mask {
                             SessionInformation => $SessionInformation,
                         },
                     );
+
+                    # show message about links in iframes, if user didn't close it already
+                    if ( !$Self->{DoNotShowBrowserLinkMessage} ) {
+                        $Self->{LayoutObject}->Block(
+                            Name => 'BrowserLinkMessage',
+                        );
+                    }
                 }
             }
             else {
