@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -593,13 +593,59 @@ sub Run {
             || IsArrayRefWithData( $Self->{ProcessList} )
             )
         {
-            @TicketIDsArray = $TicketObject->TicketSearch(
-                Result => 'ARRAY',
-                %TicketSearch,
-                %{ $TicketSearchSummary{ $Self->{Filter} } },
-                %{ $Self->{ColumnFilter} },
-                Limit => $Self->{PageShown} + $Self->{StartHit} - 1,
-            );
+
+            # Copy original column filter.
+            my %ColumnFilter = %{ $Self->{ColumnFilter} || {} };
+
+            # Change filter name accordingly.
+            my $Filter;
+            if ( $Self->{Filter} eq 'MyQueues' ) {
+                $Filter = 'QueueIDs';
+            }
+            elsif ( $Self->{Filter} eq 'MyServices' ) {
+                $Filter = 'ServiceIDs';
+
+                if ( $ColumnFilter{QueueIDs} ) {
+                    $TicketSearchSummary{ $Self->{Filter} }->{QueueIDs} = $ColumnFilter{QueueIDs};
+                }
+            }
+            elsif ( $Self->{Filter} eq 'Responsible' ) {
+                $Filter = 'ResponsibleIDs';
+            }
+            elsif ( $Self->{Filter} eq 'Locked' ) {
+                $Filter = 'LockIDs';
+            }
+
+            # Handle cases for filter columns to preserve filter value in other tab actions.
+            if ( $ColumnFilter{LockIDs} ) {
+                $TicketSearchSummary{ $Self->{Filter} }->{LockIDs} = $ColumnFilter{LockIDs};
+            }
+            elsif ( $ColumnFilter{OwnerIDs} ) {
+                $TicketSearchSummary{ $Self->{Filter} }->{OwnerIDs} = $ColumnFilter{OwnerIDs};
+            }
+
+            # Filter is used and is not in user prefered values, show no results.
+            # See bug#12808 ( https://bugs.otrs.org/show_bug.cgi?id=12808 ).
+            if (
+                $Filter
+                && IsArrayRefWithData( $TicketSearchSummary{ $Self->{Filter} }->{$Filter} )
+                && IsArrayRefWithData( $ColumnFilter{$Filter} )
+                && !grep { $ColumnFilter{$Filter}->[0] == $_ } @{ $TicketSearchSummary{ $Self->{Filter} }->{$Filter} }
+                )
+            {
+                @TicketIDsArray = ();
+            }
+
+            # Execute search.
+            else {
+                @TicketIDsArray = $TicketObject->TicketSearch(
+                    Result => 'ARRAY',
+                    %TicketSearch,
+                    %{ $TicketSearchSummary{ $Self->{Filter} } },
+                    %ColumnFilter,
+                    Limit => $Self->{PageShown} + $Self->{StartHit} - 1,
+                );
+            }
         }
         $TicketIDs = \@TicketIDsArray;
     }
@@ -616,19 +662,6 @@ sub Run {
         for my $Type ( sort keys %TicketSearchSummary ) {
             next TYPE if !$TicketSearchSummary{$Type};
 
-            # copy original column filter
-            my %ColumnFilter = %{ $Self->{ColumnFilter} || {} };
-
-            # loop through all column filter elements
-            for my $Element ( sort keys %ColumnFilter ) {
-
-                # verify if current column filter element is already present in the ticket search
-                # summary, to delete it from the column filter hash
-                if ( $TicketSearchSummary{$Type}->{$Element} ) {
-                    delete $ColumnFilter{$Element};
-                }
-            }
-
             # add process management search terms
             if ( $Self->{Config}->{IsProcessWidget} ) {
                 $TicketSearch{ 'DynamicField_' . $Self->{ProcessManagementProcessID} } = {
@@ -643,13 +676,58 @@ sub Run {
                 || IsArrayRefWithData( $Self->{ProcessList} )
                 )
             {
-                $Summary->{$Type} = $TicketObject->TicketSearch(
-                    Result => 'COUNT',
-                    %TicketSearch,
-                    %{ $TicketSearchSummary{$Type} },
-                    %{ $Self->{ColumnFilter} },
-                    %ColumnFilter,
-                );
+
+                # Copy original column filter.
+                my %ColumnFilter = %{ $Self->{ColumnFilter} || {} };
+
+                # Change filter name accordingly.
+                my $Filter;
+                if ( $Type eq 'MyQueues' ) {
+                    $Filter = 'QueueIDs';
+                }
+                elsif ( $Type eq 'MyServices' ) {
+                    $Filter = 'ServiceIDs';
+
+                    if ( $ColumnFilter{QueueIDs} ) {
+                        $TicketSearchSummary{$Type}->{QueueIDs} = $ColumnFilter{QueueIDs};
+                    }
+                }
+                elsif ( $Type eq 'Responsible' ) {
+                    $Filter = 'ResponsibleIDs';
+                }
+                elsif ( $Type eq 'MyLocks' ) {
+                    $Filter = 'LockIDs';
+                }
+
+                # Handle cases for filter columns to preserve filter value in other tab actions.
+                if ( $ColumnFilter{LockIDs} ) {
+                    $TicketSearchSummary{$Type}->{LockIDs} = $ColumnFilter{LockIDs};
+                }
+                elsif ( $ColumnFilter{OwnerIDs} ) {
+                    $TicketSearchSummary{ $Self->{Filter} }->{OwnerIDs} = $ColumnFilter{OwnerIDs};
+                }
+
+                # Filter is used and is not in user prefered values, show no results.
+                # See bug#12808 ( https://bugs.otrs.org/show_bug.cgi?id=12808 ).
+                if (
+                    $Filter
+                    && IsArrayRefWithData( $TicketSearchSummary{$Type}->{$Filter} )
+                    && IsArrayRefWithData( $ColumnFilter{$Filter} )
+                    && !grep { $ColumnFilter{$Filter}->[0] == $_ } @{ $TicketSearchSummary{$Type}->{$Filter} }
+                    )
+                {
+                    $Summary->{$Type} = 0;
+                }
+
+                # Execute search.
+                else {
+                    $Summary->{$Type} = $TicketObject->TicketSearch(
+                        Result => 'COUNT',
+                        %TicketSearch,
+                        %{ $TicketSearchSummary{$Type} },
+                        %ColumnFilter,
+                    );
+                }
             }
         }
     }
@@ -1486,7 +1564,7 @@ sub Run {
                     my %OwnerInfo = $UserObject->GetUserData(
                         UserID => $Ticket{OwnerID},
                     );
-                    $DataValue = $OwnerInfo{'UserFirstname'} . ' ' . $OwnerInfo{'UserLastname'};
+                    $DataValue = $OwnerInfo{'UserFullname'};
                 }
                 elsif ( $Column eq 'Responsible' ) {
 
@@ -1494,8 +1572,7 @@ sub Run {
                     my %ResponsibleInfo = $UserObject->GetUserData(
                         UserID => $Ticket{ResponsibleID},
                     );
-                    $DataValue = $ResponsibleInfo{'UserFirstname'} . ' '
-                        . $ResponsibleInfo{'UserLastname'};
+                    $DataValue = $ResponsibleInfo{'UserFullname'};
                 }
                 elsif (
                     $Column eq 'State'
