@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -84,7 +84,7 @@ sub ToAscii {
     $Kernel::OM->Get('Kernel::System::Encode')->EncodeInput( \$Param{String} );
 
     # get length of line for forcing line breakes
-    my $LineLength = $Self->{'Ticket::Frontend::TextAreaNote'} || 78;
+    my $LineLength = $Kernel::OM->Get('Kernel::Config')->Get('Ticket::Frontend::TextAreaNote') || 78;
 
     # find <a href=....> and replace it with [x]
     my $LinkList = '';
@@ -484,38 +484,23 @@ sub ToAscii {
         (&\#(\d+);?)
     }
     {
-        my $Chr = chr( $2 );
+        my $ChrOrig = $1;
+        my $Dec = $2;
 
-        # Make sure we get valid UTF8 code points, but skip characters from 128 to 255
-        #   (inclusive), since they are by default internally not encoded as UTF-8 for
-        #   backward compatibility reasons. See bug#12457 for more information.
-        if ( $2 < 128 || $2 > 255 ) {
-            Encode::_utf8_off($Chr);
-            $Chr = Encode::decode('utf-8', $Chr, 0);
-        }
-
-        if ( $Chr ) {
-            $Chr;
+        # Don't process UTF-16 surrogate pairs. Used on their own, these are not valid UTF-8 code
+        # points and can result in errors in old Perl versions. See bug#12588 for more information.
+        # - High Surrogate codes (U+D800-U+DBFF)
+        # - Low Surrogate codes (U+DC00-U+DFFF)
+        if ( $Dec >= 55296 && $Dec <= 57343 ) {
+            $ChrOrig;
         }
         else {
-            $1;
-        };
-    }egx;
-
-    # encode html entities like "&#x3d;"
-    $Param{String} =~ s{
-        (&\#[xX]([0-9a-fA-F]+);?)
-    }
-    {
-        my $ChrOrig = $1;
-        my $Dec = hex( $2 );
-        if ( $Dec ) {
-            my $Chr = chr( $Dec );
+            my $Chr = chr($Dec);
 
             # Make sure we get valid UTF8 code points, but skip characters from 128 to 255
             #   (inclusive), since they are by default internally not encoded as UTF-8 for
             #   backward compatibility reasons. See bug#12457 for more information.
-            if ( $Dec < 128 || $Dec > 255 ) {
+            if ( $Dec < 128 || $Dec> 255 ) {
                 Encode::_utf8_off($Chr);
                 $Chr = Encode::decode('utf-8', $Chr, 0);
             }
@@ -527,9 +512,46 @@ sub ToAscii {
                 $ChrOrig;
             }
         }
-        else {
+    }egx;
+
+    # encode html entities like "&#x3d;"
+    $Param{String} =~ s{
+        (&\#[xX]([0-9a-fA-F]+);?)
+    }
+    {
+        my $ChrOrig = $1;
+        my $Dec = hex( $2 );
+
+        # Don't process UTF-16 surrogate pairs. Used on their own, these are not valid UTF-8 code
+        # points and can result in errors in old Perl versions. See bug#12588 for more information.
+        # - High Surrogate codes (U+D800-U+DBFF)
+        # - Low Surrogate codes (U+DC00-U+DFFF)
+        if ( $Dec >= 55296 && $Dec <= 57343 ) {
             $ChrOrig;
         }
+        else {
+            if ( $Dec ) {
+                my $Chr = chr( $Dec );
+
+                # Make sure we get valid UTF8 code points, but skip characters from 128 to 255
+                #   (inclusive), since they are by default internally not encoded as UTF-8 for
+                #   backward compatibility reasons. See bug#12457 for more information.
+                if ( $Dec < 128 || $Dec > 255 ) {
+                    Encode::_utf8_off($Chr);
+                    $Chr = Encode::decode('utf-8', $Chr, 0);
+                }
+
+                if ( $Chr ) {
+                    $Chr;
+                }
+                else {
+                    $ChrOrig;
+                }
+            }
+            else {
+                $ChrOrig;
+            }
+        }
     }egx;
 
     # encode html entities like "&amp;"
