@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,6 +13,13 @@ use warnings;
 
 use MIME::Base64;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -20,11 +27,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(ConfigObject LogObject DBObject EncodeObject MainObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
-
     return $Self;
 }
 
@@ -43,17 +45,21 @@ sub FormIDRemove {
 
     for (qw(FormID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
             return;
         }
     }
-    return if !$Self->{DBObject}->Do(
-        SQL  => 'DELETE FROM web_upload_cache WHERE form_id = ?',
+
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
+        SQL => '
+            DELETE FROM web_upload_cache
+            WHERE form_id = ?',
         Bind => [ \$Param{FormID} ],
     );
+
     return 1;
 }
 
@@ -62,7 +68,7 @@ sub FormIDAddFile {
 
     for (qw(FormID Filename Content ContentType)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -73,9 +79,14 @@ sub FormIDAddFile {
     # get file size
     $Param{Filesize} = bytes::length( $Param{Content} );
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # encode attachment if it's a postgresql backend!!!
-    if ( !$Self->{DBObject}->GetDatabaseFunction('DirectBlob') ) {
-        $Self->{EncodeObject}->EncodeOutput( \$Param{Content} );
+    if ( !$DBObject->GetDatabaseFunction('DirectBlob') ) {
+
+        $Kernel::OM->Get('Kernel::System::Encode')->EncodeOutput( \$Param{Content} );
+
         $Param{Content} = encode_base64( $Param{Content} );
     }
 
@@ -83,23 +94,27 @@ sub FormIDAddFile {
     my $ContentID = $Param{ContentID};
     my $Disposition = $Param{Disposition} || '';
     if ( !$ContentID && lc $Disposition eq 'inline' ) {
+
         my $Random = rand 999999;
-        my $FQDN   = $Self->{ConfigObject}->Get('FQDN');
+        my $FQDN   = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
+
         $ContentID = "$Disposition$Random.$Param{FormID}\@$FQDN";
     }
 
     # write attachment to db
     my $Time = time();
-    return if !$Self->{DBObject}->Do(
-        SQL => 'INSERT INTO web_upload_cache '
-            . ' (form_id, filename, content_type, content_size, content, create_time_unix,'
-            . ' content_id)'
-            . ' VALUES  (?, ?, ?, ?, ?, ?, ?)',
+
+    return if !$DBObject->Do(
+        SQL => '
+            INSERT INTO web_upload_cache (form_id, filename, content_type, content_size, content,
+                create_time_unix, content_id, disposition)
+            VALUES  (?, ?, ?, ?, ?, ?, ?, ?)',
         Bind => [
             \$Param{FormID}, \$Param{Filename}, \$Param{ContentType}, \$Param{Filesize},
-            \$Param{Content}, \$Time, \$ContentID
+            \$Param{Content}, \$Time, \$ContentID, \$Param{Disposition}
         ],
     );
+
     return 1;
 }
 
@@ -108,21 +123,26 @@ sub FormIDRemoveFile {
 
     for (qw(FormID FileID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
             return;
         }
     }
+
     my @Index = @{ $Self->FormIDGetAllFilesMeta(%Param) };
     my $ID    = $Param{FileID} - 1;
     $Param{Filename} = $Index[$ID]->{Filename};
 
-    return if !$Self->{DBObject}->Do(
-        SQL  => 'DELETE FROM web_upload_cache WHERE form_id = ? AND filename = ?',
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
+        SQL => '
+            DELETE FROM web_upload_cache
+            WHERE form_id = ?
+                AND filename = ?',
         Bind => [ \$Param{FormID}, \$Param{Filename} ],
     );
+
     return 1;
 }
 
@@ -133,21 +153,28 @@ sub FormIDGetAllFilesData {
     my @Data;
     for (qw(FormID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
             return;
         }
     }
-    $Self->{DBObject}->Prepare(
-        SQL => 'SELECT filename, content_type, content_size, content, content_id'
-            . ' FROM web_upload_cache '
-            . ' WHERE form_id = ? ORDER BY create_time_unix',
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    $DBObject->Prepare(
+        SQL => '
+            SELECT filename, content_type, content_size, content, content_id, disposition
+            FROM web_upload_cache
+            WHERE form_id = ?
+            ORDER BY create_time_unix',
         Bind   => [ \$Param{FormID} ],
-        Encode => [ 1, 1, 1, 0, 1 ],
+        Encode => [ 1, 1, 1, 0, 1, 1 ],
     );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Counter++;
 
         # human readable file size
@@ -164,7 +191,7 @@ sub FormIDGetAllFilesData {
         }
 
         # encode attachment if it's a postgresql backend!!!
-        if ( !$Self->{DBObject}->GetDatabaseFunction('DirectBlob') ) {
+        if ( !$DBObject->GetDatabaseFunction('DirectBlob') ) {
             $Row[3] = decode_base64( $Row[3] );
         }
 
@@ -177,10 +204,12 @@ sub FormIDGetAllFilesData {
                 ContentType => $Row[1],
                 Filename    => $Row[0],
                 Filesize    => $Row[2],
+                Disposition => $Row[5],
                 FileID      => $Counter,
             }
         );
     }
+
     return \@Data;
 }
 
@@ -191,20 +220,27 @@ sub FormIDGetAllFilesMeta {
     my @Data;
     for (qw(FormID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
             return;
         }
     }
-    $Self->{DBObject}->Prepare(
-        SQL => 'SELECT filename, content_type, content_size, content_id'
-            . ' FROM web_upload_cache '
-            . ' WHERE form_id = ? ORDER BY create_time_unix',
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    $DBObject->Prepare(
+        SQL => '
+            SELECT filename, content_type, content_size, content_id, disposition
+            FROM web_upload_cache
+            WHERE form_id = ?
+            ORDER BY create_time_unix',
         Bind => [ \$Param{FormID} ],
     );
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Counter++;
 
         # human readable file size
@@ -228,6 +264,7 @@ sub FormIDGetAllFilesMeta {
                 ContentType => $Row[1],
                 Filename    => $Row[0],
                 Filesize    => $Row[2],
+                Disposition => $Row[4],
                 FileID      => $Counter,
             }
         );
@@ -239,10 +276,14 @@ sub FormIDCleanUp {
     my ( $Self, %Param ) = @_;
 
     my $CurrentTile = time() - ( 60 * 60 * 24 * 1 );
-    return if !$Self->{DBObject}->Do(
-        SQL  => 'DELETE FROM web_upload_cache WHERE create_time_unix < ?',
+
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
+        SQL => '
+            DELETE FROM web_upload_cache
+            WHERE create_time_unix < ?',
         Bind => [ \$CurrentTile ],
     );
+
     return 1;
 }
 
