@@ -1,7 +1,6 @@
 #!/usr/bin/perl
 # --
-# bin/otrs.LoaderCache.pl - the global test handle
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -10,12 +9,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -30,48 +29,40 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Loader;
-use Kernel::System::Encode;
-use Kernel::System::Log;
-use Kernel::System::Main;
+use Kernel::System::ObjectManager;
 
 sub PrintHelp {
     print <<"EOF";
 otrs.LoaderCache.pl - Commandline interface to the
      cache of the CSS/JavaScript loading mechanism of OTRS
 
-Usage: otrs.LoaderCache.pl -o delete
+Usage: otrs.LoaderCache.pl -o delete|generate
 
-Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 EOF
 }
 
 # get options
-my %Opts = ();
-getopt( 'ho', \%Opts );
+my %Opts;
+getopt( 'o', \%Opts );
 if ( $Opts{h} ) {
     PrintHelp();
     exit 1;
 }
 
-# create common objects
-my %CommonObject = ();
+# create object manager
 
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.Test',
-    %CommonObject,
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.Test',
+    },
 );
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
 
 # create needed objects
-$CommonObject{LoaderObject} = Kernel::System::Loader->new(%CommonObject);
 
 if ( $Opts{o} && lc( $Opts{o} ) eq 'delete' ) {
     print "Deleting all Loader cache files...\n";
-    my @DeletedFiles = $CommonObject{LoaderObject}->CacheDelete();
+    my @DeletedFiles = $Kernel::OM->Get('Kernel::System::Loader')->CacheDelete();
     if (@DeletedFiles) {
         print "The following files were deleted:\n\t";
         print join "\n\t", @DeletedFiles;
@@ -82,6 +73,26 @@ if ( $Opts{o} && lc( $Opts{o} ) eq 'delete' ) {
     }
     exit 0;
 }
+if ( $Opts{o} && lc( $Opts{o} ) eq 'generate' ) {
+    print "Generating loader cache files...\n";
+
+    # Force loader also on development systems where it might be turned off.
+    $Kernel::OM->Get('Kernel::Config')->Set(
+        Key   => 'Loader::Enabled::JS',
+        Value => 1,
+    );
+    $Kernel::OM->Get('Kernel::Config')->Set(
+        Key   => 'Loader::Enabled::CSS',
+        Value => 1,
+    );
+    my @FrontendModules = $Kernel::OM->Get('Kernel::System::Loader')->CacheGenerate();
+    for my $FrontendModule (@FrontendModules) {
+        print "    $FrontendModule\n";
+
+    }
+    print "Done.\n";
+    exit 0;
+}
 else {
     PrintHelp();
 }
