@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -40,7 +40,7 @@ my $DBDump      = '';
 getopt( 'hcrtd', \%Opts );
 if ( exists $Opts{h} ) {
     print "backup.pl - backup script\n";
-    print "Copyright (C) 2001-2016 OTRS AG, http://otrs.com/\n";
+    print "Copyright (C) 2001-2018 OTRS AG, http://otrs.com/\n";
     print "usage: backup.pl -d /data_backup_dir/ [-c gzip|bzip2] [-r 30] [-t fullbackup|nofullbackup|dbonly]\n";
     exit 1;
 }
@@ -153,22 +153,22 @@ if ( !mkdir($Directory) ) {
     die "ERROR: Can't create directory: $Directory: $!\n";
 }
 
-# backup Kernel/Config.pm
-print "Backup $Directory/Config.tar.gz ... ";
-if ( !system("tar -czf $Directory/Config.tar.gz Kernel/Config*") ) {
-    print "done\n";
-}
-else {
-    print "failed\n";
-    RemoveIncompleteBackup($Directory);
-    die "Backup failed\n";
-}
-
 # backup application
 if ($DBOnlyBackup) {
     print "Backup of filesystem data disabled by parameter dbonly ... \n";
 }
 else {
+    # backup Kernel/Config.pm
+    print "Backup $Directory/Config.tar.gz ... ";
+    if ( !system("tar -czf $Directory/Config.tar.gz Kernel/Config*") ) {
+        print "done\n";
+    }
+    else {
+        print "failed\n";
+        RemoveIncompleteBackup($Directory);
+        die "Backup failed\n";
+    }
+
     if ($FullBackup) {
         print "Backup $Directory/Application.tar.gz ... ";
         my $Excludes = "--exclude=var/tmp --exclude=js-cache --exclude=css-cache --exclude=.git";
@@ -211,7 +211,7 @@ else {
 
 # backup database
 if ( $DB =~ m/mysql/i ) {
-    print "Dump $DB rdbms ... ";
+    print "Dump $DB data to $Directory/DatabaseBackup.sql ... ";
     if ($DatabasePw) {
         $DatabasePw = "-p'$DatabasePw'";
     }
@@ -225,7 +225,7 @@ if ( $DB =~ m/mysql/i ) {
     }
 }
 else {
-    print "Dump $DB rdbms ... ";
+    print "Dump $DB data to $Directory/DatabaseBackup.sql ... ";
 
     # set password via environment variable if there is one
     if ($DatabasePw) {
