@@ -1,6 +1,5 @@
 // --
-// Core.AJAX.UnitTest.js - UnitTests
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/\n";
+// Copyright (C) 2001-2018 OTRS AG, http://otrs.com/\n";
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -236,7 +235,7 @@ Core.AJAX = (function (Namespace) {
                  Name: 'Core.AJAX.FunctionCall() simple select',
                  URL: 'sample/Core.AJAX.FunctionCall1.html',
                  Callback: function(Result) {
-                     equal(Result, "1\n2\n3\n-", 'Function call with simple data');
+                     equal(Result, "1\n2\n3\n-\n", 'Function call with simple data');
                      start();
                  }
              }
